@@ -171,7 +171,7 @@ redist.preproc <- function(adjobj, popvec, initcds = NULL, ndists = NULL,
     ## If no initial congressional districts provided, use Random Seed and Grow ##
     ## (Chen and Rodden 2013) algorithm                                         ##
     ##############################################################################
-    if(is.null(initcds) | is.na(initcds)[1]){
+    if(is.null(initcds)){
 
         ## Set up target pop, strength of constraint (10%)
         if(is.null(popcons)){
@@ -185,7 +185,7 @@ redist.preproc <- function(adjobj, popvec, initcds = NULL, ndists = NULL,
         
         cat("\n", append = TRUE)
         cat(divider, append = TRUE)
-        cat("redist.rsg(): Automated Redistricting Starts\n\n", append= TRUE)
+        cat("Using redist.rsg() to generate starting values.\n\n", append= TRUE)
         
         ## Run the algorithm
         initout <- redist.rsg(adj.list = adjlist,
@@ -198,6 +198,7 @@ redist.preproc <- function(adjobj, popvec, initcds = NULL, ndists = NULL,
         initcds <- initout$district_membership
         
     }
+
     ###########################################################
     ## Check other inputs to make sure they are right length ##
     ###########################################################
@@ -391,19 +392,85 @@ redist.preproc <- function(adjobj, popvec, initcds = NULL, ndists = NULL,
     
 }
 
+#' Combine successive runs of \code{redist.mcmc}
+#'
+#' \code{redist.combine} is used to combine successive runs of \code{redist.mcmc}
+#' into a single data object
+#'
+#' @usage redist.combine(savename, nsims, nloop, nthin, nunits, temper)
+#'
+#' @param savename The name (without the loop or \code{.RData} suffix)
+#' of the saved simulations.
+#' @param nsims The number of simulations in each loop.
+#' @param nloop The number of loops being combined.
+#' @param nthin How much to thin the simulations being combined.
+#' @param nunits The number of geographic units from the simulations.
+#' @param temper Wheterh simulated tempering was used (1) or not (0)
+#' in the simulations. Default is 0.
+#'
+#' @details This function allows users to combine multiple successive runs of
+#' \code{redist.mcmc} into a single \code{redist} object for analysis.
+#'
+#' @return \code{redist.combine} returns an object of class "redist". The object
+#' \code{redist} is a list that contains the folowing components (the
+#' inclusion of some components is dependent on whether tempering
+#' techniques are used):
+#' \item{partitions}{Matrix of congressional district assignments generated by the
+#' algorithm. Each row corresponds to a geographic unit, and each column
+#' corresponds to a simulation.}
+#' \item{distance_parity}{Vector containing the maximum distance from parity for
+#' a particular simulated redistricting plan.}
+#' \item{mhdecisions}{A vector specifying whether a proposed redistricting plan
+#' was accepted (1) or rejected (0) in a given iteration.}
+#' \item{mhprob}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm.}
+#' \item{pparam}{A vector containing the draw of the \code{p} parameter for each
+#' simulation, which dictates the number of swaps attempted.}
+#' \item{constraint_pop}{A vector containing the value of the population
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_compact}{A vector containing the value of the compactness
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_segregation}{A vector containing the value of the
+#' segregation constraint for each accepted redistricting plan.}
+#' \item{constraint_similar}{A vector containing the value of the similarity
+#' constraint for each accepted redistricting plan.}
+#' \item{beta_sequence}{A vector containing the value of beta for each iteration
+#' of the algorithm. Returned when tempering is being used.}
+#' \item{mhdecisions_beta}{A vector specifying whether a proposed beta value was
+#' accepted (1) or rejected (0) in a given iteration of the algorithm. Returned
+#' when tempering is being used.}
+#' \item{mhprob_beta}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm. Returned when tempering
+#' is being used.}
+#'
+#' @references Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander Tarr.
+#' (2016) "A New Automated Redistricting Simulator Using Markov Chain Monte
+#' Carlo." Working Paper. Available at
+#' \url{http://imai.princeton.edu/research/files/redist.pdf}.
+#'
+#' @examples
+#' \dontrun{
+#' data(algdat.pfull)
+#'
+#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,Imai and
+#' Tarr (2015)
+#'
+#' ## Get an initial partition
+#' set.seed(1)
+#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#'
+#' ## Run the algorithm
+#' alg_253 <- redist.mcmc(adjobj = algdat.pfull$adjlist,
+#' popvec = algdat.pfull$precinct.data$pop,
+#' initcds = initcds,
+#' nsims = 10000, nloops = 2, savename = "test")
+#' out <- redist.combine(savename = "test", nsims = 10000, nloop = 2,
+#' nthin = 10, nunits = length(algdat.pfull$adjlist))
+#' }
+#' @export
 redist.combine <- function(savename, nsims, nloop, nthin, nunits, temper = 0
                            ){
 
-    ########################
-    ## Inputs to function ##
-    ########################
-    ## savename - filename
-    ## nsims - number of simulations in each loop
-    ## nloop - number of loops to run simulations
-    ## nthin - how much to thin the simulations
-    ## nunits - number of geographic units
-    ## temper - whether tempering is used in the simulations
-
     ##############################
     ## Set up container objects ##
     ##############################
@@ -411,6 +478,7 @@ redist.combine <- function(savename, nsims, nloop, nthin, nunits, temper = 0
                          ncol = (nsims * nloop / nthin))
 
     distance_parity <- rep(NA, (nsims * nloop / nthin))
+    distance_original <- rep(NA, (nsims * nloop / nthin))
     mhdecisions <- rep(NA, (nsims * nloop / nthin))
     mhprob <- rep(NA, (nsims * nloop / nthin))
     pparam <- rep(NA, (nsims * nloop / nthin))
@@ -442,6 +510,7 @@ redist.combine <- function(savename, nsims, nloop, nthin, nunits, temper = 0
         partitions[1:nunits, ind] <- algout$partitions[,indthin]
 
         distance_parity[ind] <- algout$distance_parity[indthin]
+        distance_original[ind] <- algout$distance_original[indthin]
         mhdecisions[ind] <- algout$mhdecisions[indthin]
         mhprob[ind] <- algout$mhprob[indthin]
         pparam[ind] <- algout$pparam[indthin]
@@ -468,6 +537,7 @@ redist.combine <- function(savename, nsims, nloop, nthin, nunits, temper = 0
     }
     algout$partitions <- partitions
     algout$distance_parity <- distance_parity
+    algout$distance_original <- distance_original
     algout$mhdecisions <- mhdecisions
     algout$mhprob <- mhprob
     algout$pparam <- pparam
@@ -493,6 +563,150 @@ redist.combine <- function(savename, nsims, nloop, nthin, nunits, temper = 0
     
 }
 
+#' MCMC Redistricting Simulator
+#'
+#' \code{redist.mcmc} is used to simulate Congressional redistricting
+#' plans using Markov Chain Monte Carlo methods.
+#'
+#' @usage redist.mcmc(adjobj, popvec, nsims, ndists = NULL, initcds = NULL,
+#' loopscompleted = 0, nloop = 1, nthin = 1, eprob = 0.05, lambda = 0,
+#' popcons = NULL, grouppopvec = NULL, ssdmat = NULL,
+#' beta = 0, temper = "none", constraint = "none",
+#' betaseq = "powerlaw", betaseqlength = 10,
+#' betaweights = NULL,
+#' adjswaps = TRUE, rngseed = NULL, maxiterrsg = 5000,
+#' adapt_lambda = FALSE, adapt_eprob = FALSE,
+#' contiguitymap = "rooks", exact_mh = FALSE, savename = NULL, verbose = TRUE)
+#'
+#' @param adjobj An adjacency matrix, list, or object of class
+#' "SpatialPolygonsDataFrame."
+#' @param popvec A vector containing the populations of each geographic
+#' unit
+#' @param nsims The number of simulations run before a save point.
+#' @param ndists The numbe of congressional districts. The default is
+#' \code{NULL}.
+#' @param initcds A vector containing the congressional district labels
+#' of each geographic unit. The default is \code{NULL}. If not provided,
+#' random and contiguous congressional district assignments will be generated
+#' using \code{redist.rsg}.
+#' @param loopscompleted Number of save points reached by the
+#' algorithm. The default is \code{0}.
+#' @param nloop The total number of save points for the algorithm. The
+#' default is \code{1}. Note that the total number of simulations run
+#' will be \code{nsims} * \code{nloop}.
+#' @param nthin The amount by which to thin the Markov Chain. The
+#' default is \code{1}.
+#' @param eprob The probability of keeping an edge connected. The
+#' default is \code{0.05}.
+#' @param lambda The parameter detmerining the number of swaps to attempt
+#' each iteration fo the algoirhtm. The number of swaps each iteration is
+#' equal to Pois(\code{lambda}) + 1. The default is \code{0}.
+#' @param popcons The strength of the hard population
+#' constraint. \code{popcons} = 0.05 means that any proposed swap that
+#' brings a district more than 5\% away from population parity will be
+#' rejected. The default is \code{NULL}.
+#' @param grouppopvec A vector of populations for some sub-group of
+#' interest. The default is \code{NULL}.
+#' @param ssdmat A matrix of squared distances between geographic
+#' units. The default is \code{NULL}.
+#' @param beta The strength of the target strength in the MH ratio.
+#' The default is 0.
+#' @param temper Type of tempering algorithm to use.
+#' Accepts \code{simulated}, \code{parallel}, or \code{none}
+#' (no tempering applied). The default is \code{none}.
+#' @param constraint Which constraint to apply. Accepts \code{compact},
+#' \code{segregation}, \code{population}, \code{similarity}, or \code{none}
+#' (no constraint applied). The default is \code{none}.
+#' @param betaseq Sequence of beta values for tempering. The default is
+#' \code{powerlaw} (see Fifield et. al (2015) for details).
+#' @param betaseqlength Length of beta sequence desired for
+#' tempering. The default is \code{10}.
+#' @param betaweights Sequence of weights for different values of
+#' beta. Allows the user to upweight certain values of beta over
+#' others. The default is \code{NULL} (equal weighting).
+#' @param adjswaps Flag to restrict swaps of beta so that only
+#' values adjacent to current constraint are proposed. The default is
+#' \code{TRUE}.
+#' @param rngseed Allows the user to set the seed for the
+#' simulations. Default is \code{NULL}.
+#' @param maxiterrsg Maximum number of iterations for random seed-and-grow
+#' algorithm to generate starting values. Default is 5000.
+#' @param adapt_lambda Whether to adaptively tune the lambda parameter so that the Metropolis-Hastings
+#' acceptance probability falls between 20\% and 40\%. Default is FALSE.
+#' @param adapt_eprob Whether to adaptively tune the edgecut probability parameter so that the
+#' Metropolis-Hastings acceptance probability falls between 20\% and 40\%. Default is
+#' FALSE.
+#' @param contiguitymap Use queens or rooks distance criteria for generating an
+#' adjacency list from a "SpatialPolygonsDataFrame" data type.
+#' Default is "rooks".
+#' @param exact_mh Whether to use the approximate (0) or exact (1)
+#' Metropolis-Hastings ratio calculation for accept-reject rule. Default is FALSE.
+#' @param savename Filename to save simulations. Default is \code{NULL}.
+#' @param verbose Whether to print initialization statement.
+#' Default is \code{TRUE}.
+#'
+#' @details This function allows users to simulate redistricting plans
+#' using Markov Chain Monte Carlo methods. Several constraints
+#' correspoding to substantive requirements in the redistricting process
+#' are implemented, including population parity and geographic
+#' compactness. In addition, the function includes multiple-swap and
+#' simulated tempering functionality to improve the mixing of the Markov
+#' Chain.
+#'
+#' @return \code{redist.mcmc} returns an object of class "redist". The object
+#' \code{redist} is a list that contains the folowing components (the
+#' inclusion of some components is dependent on whether tempering
+#' techniques are used):
+#' \item{partitions}{Matrix of congressional district assignments generated by the
+#' algorithm. Each row corresponds to a geographic unit, and each column
+#' corresponds to a simulation.}
+#' \item{distance_parity}{Vector containing the maximum distance from parity for
+#' a particular simulated redistricting plan.}
+#' \item{mhdecisions}{A vector specifying whether a proposed redistricting plan
+#' was accepted (1) or rejected (0) in a given iteration.}
+#' \item{mhprob}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm.}
+#' \item{pparam}{A vector containing the draw of the \code{p} parameter for each
+#' simulation, which dictates the number of swaps attempted.}
+#' \item{constraint_pop}{A vector containing the value of the population
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_compact}{A vector containing the value of the compactness
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_segregation}{A vector containing the value of the
+#' segregation constraint for each accepted redistricting plan.}
+#' \item{constraint_similar}{A vector containing the value of the similarity
+#' constraint for each accepted redistricting plan.}
+#' \item{beta_sequence}{A vector containing the value of beta for each iteration
+#' of the algorithm. Returned when tempering is being used.}
+#' \item{mhdecisions_beta}{A vector specifying whether a proposed beta value was
+#' accepted (1) or rejected (0) in a given iteration of the algorithm. Returned
+#' when tempering is being used.}
+#' \item{mhprob_beta}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm. Returned when tempering
+#' is being used.}
+#'
+#' @references Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander
+#' Tarr. (2016) "A New Automated Redistricting Simulator Using Markov Chain Monte
+#' Carlo." Working Paper. Available at
+#' \url{http://imai.princeton.edu/research/files/redist.pdf}.
+#'
+#' @examples
+#' \dontrun{
+#' data(algdat.pfull)
+#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,
+#' ## Imai and Tarr (2015)
+#'
+#' ## Get an initial partition
+#' set.seed(1)
+#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#'
+#' ## Run the algorithm
+#' alg_253 <- redist.mcmc(adjobj = algdat.pfull$adjlist,
+#' popvec = algdat.pfull$precinct.data$pop,
+#' initcds = initcds,
+#' nsims = 10000)
+#' }
+#' @export
 redist.mcmc <- function(adjobj, popvec, nsims, ndists = NULL, initcds = NULL,
                         loopscompleted = 0, nloop = 1, nthin = 1, eprob = 0.05,
                         lambda = 0, popcons = NULL, grouppopvec = NULL,
@@ -501,47 +715,11 @@ redist.mcmc <- function(adjobj, popvec, nsims, ndists = NULL, initcds = NULL,
                         betaseq = "powerlaw", betaseqlength = 10,
                         betaweights = NULL, 
                         adjswaps = TRUE, rngseed = NULL, maxiterrsg = 5000,
-                        contiguitymap = "rooks", exact_mh = 0, savename = NULL, verbose = TRUE
+                        adapt_lambda = FALSE, adapt_eprob = FALSE,
+                        contiguitymap = "rooks", exact_mh = FALSE, savename = NULL,
+                        verbose = TRUE
                         ){
 
-    #########################
-    ## Inputs to function: ##
-    #########################
-    ## adjobj - adjacency object of geographic units. Accepts adjlist or adjmat
-    ## popvec - population of each of the units
-    ## nsims - number of iterations to run the algorithm
-    ## ndists - Target number of congressional districts. Default is NULL
-    ## initcds - initial congressional units. Must be contiguous partitions. Default is Null
-    ## loopscompleted - number of loops completed. Default is 0
-    ## nloop - Total number of loops desired across all simulations.
-    ## nthin - How much to thin the chain. Defaulted to 1 (keep everything)
-    ## eprob - edgecut probability. Defaulted to 0.05
-    ## lambda - expected number of swaps attempted per algorithm iteration.
-    ##          Default set to 0 (single swap).
-    ## popcons - strength of hard population constraint. Defaulted to no
-    ##           constraint. popcons = 0.01 implies a 1% population constraint.
-    ## grouppopvec - vector of populations for a minority group. To be used
-    ##               in conjunction with the segregation M-H constraint
-    ## ssdmat - matrix of squared distances between population units.
-    ##          To be used when applying the compactness constraint.
-    ## beta - target strength of constraint in MH ratio. Defaults to 0.
-    ## temper - whether to use tempering (parallel or simulated) algorithms.
-    ##          Defaults to `none` (no tempering)
-    ## constraint - which constraint to apply. Defaults to `none` (no tempering)
-    ## betaseq - Spacing for beta sequence if tempering. Default is power law
-    ## betaseqlength - Number of temperatures in the beta sequence. Default is
-    ##                 ten
-    ## betaweights - Vector of weights for beta sequence. Provided by user
-    ## adjswaps - Flag for adjacent swaps for geyer-thompson tempering or MPI
-    ##            parallel tempering. Default to TRUE
-    ## rngseed - Random number generator seed number. Provided by user
-    ## maxiterrsg - Maximum number of iterations for random seed-and-grow algorithm
-    ## contiguitymap - Use queens distance or rooks distance for creating an adjlist
-    ##                 from map. Defaults to rooks.
-    ## exact_mh - Use exact metropolis hastings with boundary correction. Default to 0
-    ## savename - Where to save the simulations
-    ## verbose - whether to print initialization script
-
     if(verbose){
         ## Initialize ##
         divider <- c(paste(rep("=", 20), sep = "", collapse = ""), "\n")
@@ -579,6 +757,22 @@ redist.mcmc <- function(adjobj, popvec, nsims, ndists = NULL, initcds = NULL,
     if(!is.null(rngseed) & is.numeric(rngseed)){
         set.seed(rngseed)
     }
+
+    if(adapt_lambda){
+        adapt_lambda <- 1
+    }else{
+        adapt_lambda <- 0
+    }
+    if(adapt_eprob){
+        adapt_eprob <- 1
+    }else{
+        adapt_eprob <- 0
+    }
+    if(exact_mh){
+        exact_mh <- 1
+    }else{
+        exact_mh <- 0
+    }
     
     #####################
     ## Preprocess data ##
@@ -693,7 +887,9 @@ redist.mcmc <- function(adjobj, popvec, nsims, ndists = NULL, initcds = NULL,
                        anneal_beta_segregation = preprocout$params$temperbetaseg,
                        anneal_beta_similar = preprocout$params$temperbetasimilar,
                        adjswap = preprocout$params$adjswaps,
-                       exact_mh = exact_mh)
+                       exact_mh = exact_mh,
+                       adapt_lambda = adapt_lambda,
+                       adapt_eprob = adapt_eprob)
 
         class(algout) <- "redist"
 
@@ -736,21 +932,73 @@ redist.mcmc <- function(adjobj, popvec, nsims, ndists = NULL, initcds = NULL,
 
 }
 
+#' Diagnostic plotting functionality for MCMC redistricting.
+#'
+#' \code{redist.diagplot} generates several common MCMC diagnostic plots.
+#'
+#' @usage redist.diagplot(sumstat,
+#' plot = c("trace", "autocorr", "densplot", "mean", "gelmanrubin"),
+#' logit = FALSE, savename = NULL)
+#'
+#' @param sumstat A vector, list, \code{mcmc} or \code{mcmc.list} object
+#' containing a summary statistic of choice.
+#' @param plot The type of diagnostic plot to generate: one of "trace",
+#' "autocorr", "densplot", "mean", "gelmanrubin". If \code{plot = "gelmanrubin"},
+#' the input \code{sumstat} must be of class \code{mcmc.list} or \code{list}.
+#' @param logit Flag for whether to apply the logistic transformation for the
+#' summary statistic. The default is \code{FALSE}.
+#' @param savename Filename to save the plot. Default is \code{NULL}.
+#'
+#' @details This function allows users to generate several standard diagnostic
+#' plots from the MCMC literature, as implemented by Plummer et. al (2006).
+#' Diagnostic plots implemented include trace plots, autocorrelation plots,
+#' density plots, running means, and Gelman-Rubin convergence diagnostics
+#' (Gelman & Rubin 1992).
+#'
+#' @return Returns a plot of file type \code{.pdf}.
+#'
+#' @references Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander
+#' Tarr. (2016) "A New Automated Redistricting Simulator Using Markov Chain Monte
+#' Carlo." Working Paper. Available at
+#' \url{http://imai.princeton.edu/research/files/redist.pdf}.
+#'
+#' Gelman, Andrew and Donald Rubin. (1992) "Inference from iterative simulations
+#' using multiple sequences (with discussion)." Statistical Science.
+#'
+#' Plummer, Martin, Nicky Best, Kate Cowles and Karen Vines. (2006) "CODA:
+#' Convergence Diagnosis and Output Analysis for MCMC." R News.
+#'
+#' @examples
+#' \dontrun{
+#' data(algdat.pfull)
+#'
+#' ## Get an initial partition
+#' set.seed(1)
+#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#'
+#' ## 25 precinct, three districts - no pop constraint ##
+#' alg_253 <- redist.mcmc(adjobj = algdat.pfull$adjlist,
+#' popvec = algdat.pfull$precinct.data$pop,
+#' initcds = initcds,nsims = 10000)
+#'
+#' ## Get Republican Dissimilarity Index from simulations
+#' rep_dmi_253 <- redist.segcalc(alg_253,
+#' algdat.pfull$precinct.data$repvote,
+#' algdat.pfull$precinct.data$pop)
+#'
+#' ## Generate diagnostic plots
+#' redist.diagplot(rep_dmi_253, plot = "trace")
+#' redist.diagplot(rep_dmi_253, plot = "autocorr")
+#' redist.diagplot(rep_dmi_253, plot = "densplot")
+#' redist.diagplot(rep_dmi_253, plot = "mean")
+#' }
+#' @export
 redist.diagplot <- function(sumstat,
                             plot = c("trace", "autocorr", "densplot",
                                 "mean", "gelmanrubin"),
                             logit = FALSE, savename = NULL
                             ){
 
-    ########################
-    ## Inputs to function ##
-    ########################
-    ## rediststat - a vector of a summary stat for each redistricting plan
-    ## plot - type of plot to create. Inputs are "trace," "autocorr", "densplot",
-    ##        "mean", or "gelmanrubin"
-    ## logit - logit transformation on dissimilarity index. Default = FALSE
-    ## savename - Name to save under. Default = NULL
-
     ##############
     ## Warnings ##
     ##############
@@ -844,6 +1092,102 @@ redist.diagplot <- function(sumstat,
 
 }
 
+#' Inverse probability reweighting for MCMC Redistricting
+#'
+#' \code{redist.ipw} properly weights and resamples simulated redistricting plans
+#' so that the set of simulated plans resemble a random sample from the
+#' underlying distribution. \code{redist.ipw} is used to correct the sample when
+#' population parity, geographic compactness, or other constraints are
+#' implemented.
+#'
+#' @usage redist.ipw(algout,
+#' resampleconstraint = c("pop", "compact", "segregation", "similar"),
+#' targetbeta, targetpop = NULL, temper = 0)
+#'
+#' @param algout An object of class "redist".
+#' @param resampleconstraint The constraint implemented in the simulations: one
+#' of "pop", "compact", "segregation", or "similar".
+#' @param targetbeta The target value of the constraint.
+#' @param targetpop The desired level of population parity. \code{targetpop} =
+#' 0.01 means that the desired distance from population parity is 1\%. The
+#' default is \code{NULL}.
+#' @param temper A flag for whether simulated tempering was used to improve the
+#' mixing of the Markov Chain. The default is \code{1}.
+#'
+#' @details This function allows users to resample redistricting plans using
+#' inverse probability weighting techniques described in Rubin (1987). This
+#' techniques reweights and resamples redistricting plans so that the resulting
+#' sample is representative of a random sample from the uniform distribution.
+#'
+#' @return \code{redist.ipw} returns an object of class "redist". The object
+#' \code{redist} is a list that contains the folowing components (the
+#' inclusion of some components is dependent on whether tempering
+#' techniques are used):
+#' \item{partitions}{Matrix of congressional district assignments generated by the
+#' algorithm. Each row corresponds to a geographic unit, and each column
+#' corresponds to a simulation.}
+#' \item{distance_parity}{Vector containing the maximum distance from parity for
+#' a particular simulated redistricting plan.}
+#' \item{mhdecisions}{A vector specifying whether a proposed redistricting plan
+#' was accepted (1) or rejected (0) in a given iteration.}
+#' \item{mhprob}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm.}
+#' \item{pparam}{A vector containing the draw of the \code{p} parameter for each
+#' simulation, which dictates the number of swaps attempted.}
+#' \item{constraint_pop}{A vector containing the value of the population
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_compact}{A vector containing the value of the compactness
+#' constraint for each accepted redistricting plan.}
+#' \item{constraint_segregation}{A vector containing the value of the
+#' segregation constraint for each accepted redistricting plan.}
+#' \item{constraint_similar}{A vector containing the value of the similarity
+#' constraint for each accepted redistricting plan.}
+#' \item{beta_sequence}{A vector containing the value of beta for each iteration
+#' of the algorithm. Returned when tempering is being used.}
+#' \item{mhdecisions_beta}{A vector specifying whether a proposed beta value was
+#' accepted (1) or rejected (0) in a given iteration of the algorithm. Returned
+#' when tempering is being used.}
+#' \item{mhprob_beta}{A vector containing the Metropolis-Hastings acceptance
+#' probability for each iteration of the algorithm. Returned when tempering
+#' is being used.}
+#'
+#' @references Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander
+#' Tarr. (2016) "A New Automated Redistricting Simulator Using Markov Chain
+#' Monte Carlo." Working Paper.
+#' Available at \url{http://imai.princeton.edu/research/files/redist.pdf}.
+#'
+#' Rubin, Donald. (1987) "Comment: A Noniterative Sampling/Importance Resampling
+#' Alternative to the Data Augmentation Algorithm for Creating a Few Imputations
+#' when Fractions of Missing Information are Modest: the SIR Algorithm."
+#' Journal of the American Statistical Association.
+#'
+#' @examples \dontrun{
+#' data(algdat.p20)
+#'
+#' ## Code to run the simulations in Figure 4 of Fifield, Higgins,
+#' ## Imai and Tarr (2015)
+#'
+#' ## Get an initial partition
+#' set.seed(1)
+#' initcds <- algdat.p20$cdmat[,sample(1:ncol(algdat.p20$cdmat), 1)]
+#'
+#' ## Vector of beta weights
+#' betaweights <- rep(NA, 10); for(i in 1:10){betaweights[i] <- 4^i}
+#'
+#' ## Run simulations - tempering population constraint
+#' alg_253_20_st <- redist.mcmc(adjobj = algdat.p20$adjlist,
+#' popvec = algdat.p20$precinct.data$pop,
+#' initcds = initcds, nsims = 10000, betapop = -5.4,
+#' betaweights = betaweights, temperbetapop = 1)
+#'
+#' ## Resample using inverse probability weighting.
+#' ## Target distance from parity is 20%
+#' alg_253_20_st <- redist.ipw(alg_253_20_st,
+#' resampleconstraint = "pop",
+#' targetbeta = -5.4,
+#' targetpop = .2, temper = 1)
+#' }
+#' @export
 redist.ipw <- function(algout,
                        resampleconstraint = c("pop", "compact",
                            "segregation", "similar"),
@@ -852,15 +1196,6 @@ redist.ipw <- function(algout,
                        temper = 0)
 {
 
-    #########################
-    ## Inputs to function: ##
-    #########################
-    ## algout - output of redist.mcmc. Must be of class redist
-    ## resampleconstraint - index we constraint on to form target distribution.
-    ## targetbeta - target beta value
-    ## targetpop - specified target population. Default is null
-    ## temper - whether we are tempering on the resampleconstraint
-
     ## Warnings:
     if(missing(algout) | class(algout) != "redist"){
         stop("Please provide a proper redist object")
@@ -917,18 +1252,58 @@ redist.ipw <- function(algout,
     
 }
 
+#' Segregation index calculation for MCMC redistricting.
+#'
+#' \code{redist.segcalc} calculates the dissimilarity index of segregation (see
+#' Massey \& Denton 1987 for more details) for a specified subgroup under any
+#' redistricting plan.
+#'
+#' @usage redist.segcalc(algout, grouppop, fullpop)
+#'
+#' @param algout A matrix of congressional district assignments or a
+#' redist object.
+#' @param grouppop A vector of populations for some subgroup of interest.
+#' @param fullpop A vector containign the populations of each geographic unit.
+#'
+#' @return \code{redist.segcalc} returns a vector where each entry is the
+#' dissimilarity index of segregation (Massey & Denton 1987) for each
+#' redistricting plan in \code{algout}.
+#'
+#' @references Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander
+#' Tarr. (2016) "A New Automated Redistricting Simulator Using Markov Chain
+#' Monte Carlo." Working Paper. Available at
+#' \url{http://imai.princeton.edu/research/files/redist.pdf}.
+#'
+#' Massey, Douglas and Nancy Denton. (1987) "The Dimensions of Social
+#' Segregation". Social Forces.
+#'
+#' @examples
+#' \dontrun{
+#' data(algdat.pfull)
+#'
+#' ## Code to run the simulations in Figure 4 of Fifield, Higgins,
+#' ## Imai and Tarr (2015)
+#'
+#' ## Get an initial partition
+#' set.seed(1)
+#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#'
+#' ## Run simulations
+#' alg_253 <- redist.mcmc(adjobj = algdat.pfull$adjlist,
+#' popvec = algdat.pfull$precinct.data$pop,
+#' initcds = initcds, nsims = 10000)
+#'
+#' ## Get Republican Dissimilarity Index from simulations
+#' rep_dmi_253 <- redist.segcalc(alg_253,
+#' algdat.pfull$precinct.data$repvote,
+#' algdat.pfull$precinct.data$pop)
+#' }
+#' @export
 redist.segcalc <- function(algout,
                            grouppop,
                            fullpop)
 {
 
-    ########################
-    ## Inputs to function ##
-    ########################
-    ## algout: a matrix of congressional district assignments or a redist object
-    ## grouppop: a vector of populations for some subgroup
-    ## fullpop: a vector of populations for a geographic district
-
     ## Warnings
     if(missing(algout) | !(class(algout) %in% c("data.frame", "matrix", "redist"))){
         stop("Please provide either a redist object or a proper matrix of congessional districts")
